@@ -5,6 +5,10 @@ import sys
 
 from teramesh_hardware_tester.tester import getch
 
+try:
+    import RPi.GPIO as GPIO
+except ImportError:
+    GPIO = None
 
 logger = logging.getLogger('test')
 
@@ -12,6 +16,17 @@ logger = logging.getLogger('test')
 test_calibration_temperature = None
 test_calibration_humidity = None
 
+RELAY_COMMON_GPIO = 5
+RELAY_GPIO_MAP = {
+    1: 4,
+    2: 17,
+    3: 27,
+    4: 22,
+    5: 23,
+    6: 24,
+    7: 25,
+}
+
 
 async def setup(AT):
     global test_calibration_temperature
@@ -73,40 +88,52 @@ async def test_btn(AT):
     await AT.TESTBTN.expect_ok_or_error(timeout=15)
 
 
-async def test_relays(AT):
-
-    import RPi.GPIO as GPIO
-
-    RELAY_COMMON_GPIO = 5
-    RELAY_GPIO_MAP = {
-        1: 4,
-        2: 17,
-        3: 27,
-        4: 22,
-        6: 24,
-    }
-
+def relays_setup():
+    if GPIO is None:
+        assert False, 'RPi GPIO module is not installed!'
     GPIO.setmode(GPIO.BCM)
     GPIO.setup(RELAY_COMMON_GPIO, GPIO.OUT)
     GPIO.output(RELAY_COMMON_GPIO, GPIO.HIGH)
     for relay_pin in RELAY_GPIO_MAP.values():
         GPIO.setup(relay_pin, GPIO.IN, pull_up_down=GPIO.PUD_DOWN)
 
+async def _test_relay(AT, relay_no):
+    relays_setup()
     try:
         await AT.TESTRELAY0.execute()
         try:
             await AT.TESTRELAY0.expect_ok_or_error()
         except Exception:
             pass
-        for relay_no, relay_pin in RELAY_GPIO_MAP.items():
-            await getattr(AT, f'TESTRELAY{relay_no}').execute()
-            await getattr(AT, f'TESTRELAY{relay_no}').expect_ok_or_error()
-            await asyncio.sleep(0.1)
-            assert GPIO.input(relay_pin), f'Relay {relay_no} did not open'
+        relay_pin = RELAY_GPIO_MAP[relay_no]
+        await getattr(AT, f'TESTRELAY{relay_no}').execute()
+        await getattr(AT, f'TESTRELAY{relay_no}').expect_ok_or_error()
+        await asyncio.sleep(0.1)
+        assert GPIO.input(relay_pin), f'Relay {relay_no} did not open'
         await AT.TESTRELAY0.execute()
         await AT.TESTRELAY0.expect_ok_or_error()
         await asyncio.sleep(0.1)
-        for relay_no, relay_pin in RELAY_GPIO_MAP.items():
-            assert not GPIO.input(relay_pin), f'Relay {relay_no} did not close'
+        assert not GPIO.input(relay_pin), f'Relay {relay_no} did not close'
     finally:
         GPIO.cleanup()
+
+async def test_relay1(AT):
+    await _test_relay(AT, 1)
+
+async def test_relay2(AT):
+    await _test_relay(AT, 2)
+
+async def test_relay3(AT):
+    await _test_relay(AT, 3)
+
+async def test_relay4(AT):
+    await _test_relay(AT, 4)
+
+async def test_relay5(AT):
+    await _test_relay(AT, 5)
+
+async def test_relay6(AT):
+    await _test_relay(AT, 6)
+
+async def test_relay7(AT):
+    await _test_relay(AT, 7)
